@@ -1,4 +1,4 @@
 #!/bin/bash
 rm -Rf dist/*
 python3 setup.py sdist
-python3 -m twine upload dist/*
\ No newline at end of file
+twine upload dist/*
