@@ -1,9 +1,10 @@
 # flake8: noqa
+# include functions for easy reference from pq prefix
 from pyqstrat.pq_utils import *
 from pyqstrat.pq_types import *
+from pyqstrat.pq_io import *
 from pyqstrat.holiday_calendars import *
 from pyqstrat.markets import *
-from pyqstrat.trade_bars import *
 from pyqstrat.account import * 
 from pyqstrat.strategy import *
 from pyqstrat.portfolio import *
@@ -12,4 +13,5 @@ from pyqstrat.plot import *
 from pyqstrat.interactive_plot import *
 from pyqstrat.evaluator import *
 from pyqstrat.pyqstrat_cpp import *
-from pyqstrat.marketdata_processor import *
+from pyqstrat.pyqstrat_io import *
+
